@@ -3,9 +3,8 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.1001';
+our $VERSION = '0.1002';
 
-use Carp;
 use List::MoreUtils qw/ any first_index /;
 use Moo;
 use Music::Scales;
@@ -192,7 +191,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.1001
+version 0.1002
 
 =head1 SYNOPSIS
 
@@ -211,7 +210,7 @@ version 0.1001
   $roman = $mtr->parse('C');      # III (major)
   $roman = $mtr->parse('Cm9/G');  # iii9/VII (minor ninth with seven bass)
   $roman = $mtr->parse('Cm9/Bb'); # iii9/bii (minor ninth with flat-two bass)
-  $roman = $mtr->parse('D sus4'); # IV sus4
+  $roman = $mtr->parse('D sus4'); # IV sus4 (major suspended)
   $roman = $mtr->parse('DMaj7');  # IV maj7 (major seventh)
   $roman = $mtr->parse('E7');     # V7 (dominant seventh)
   $roman = $mtr->parse('Em7');    # v7 (minor seventh)
@@ -327,6 +326,8 @@ L<https://en.wikipedia.org/wiki/Roman_numeral_analysis>
 For example usage, check out the files F<eg/roman> and F<eg/basslines>
 in L<Music::BachChoralHarmony>.
 
+L<App::MusicTools> C<vov> is the reverse of this module, and is significantly powerful.
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
